﻿using UnityEngine;
using UnityEngine.Events;
using PixelCrushers;
using PixelCrushers.QuestMachine;

public class QuestNodeListener : MonoBehaviour, IMessageHandler
{
    public StringField requiredQuestID;
    public StringField requiredQuestNodeID;
    [Space]
    public UnityEvent OnNodeActive;
    public UnityEvent OnNodeInactive;

    internal bool NodeStateActive;

    void Start()
    {

    }

    void OnEnable()
    {
        MessageSystem.AddListener(this, QuestMachineMessages.QuestStateChangedMessage, requiredQuestID);
    }

    void OnDisable()
    {
        MessageSystem.RemoveListener(this);
    }

    public void OnMessage(MessageArgs messageArgs)
    {

        // "Quest State Changed" is sent when a quest state or quest node state changes. 
        // - Parameter: Quest ID. 
        // - Value 0: [StringField] Quest node ID, or null for main quest state.
        // - Value 1: [QuestState] / [QuestNodeState] New state.
        if (messageArgs.values[0] == null)
        {
            // If value 0 is null, this is the main quest state so just exit:
            return;
        }
        else
        {

            string questID = messageArgs.parameter;
            StringField questNodeID = (StringField)messageArgs.values[0];
            QuestNodeState questNodeState = (QuestNodeState)messageArgs.values[1];

            if ((questID == requiredQuestID.value) && (questNodeID.value == requiredQuestNodeID.value))
            {
           
                // This is the quest node we're interested in, so set the quest pointer based on the node's current state:
                if (questNodeState == QuestNodeState.Active)
                {
                    // (Quest node is active)
                    OnNodeActive.Invoke();
                    Debug.Log(requiredQuestID + " is in " + requiredQuestNodeID + " Node");
                    NodeStateActive = true;
                }

                else
                {
                    // (Quest node is not active)
                    OnNodeInactive.Invoke();
                    Debug.Log(requiredQuestID + " is out of " + requiredQuestNodeID + " Node");
                    NodeStateActive = false;
                }

            }
        }
    }


    public void CheckIfNodeIsActive()
    {
        // This is the quest node we're interested in, so set the quest pointer based on the node's current state:
        if (NodeStateActive == true)
        {
            // (Quest node is active)
            OnNodeActive.Invoke();
            Debug.Log(requiredQuestID + " is in " + requiredQuestNodeID + " Node");
        }

        //if (NodeStateActive == false)
        //{
            //(Quest node is not active)
            //OnNodeInactive.Invoke();
            //Debug.Log(requiredQuestID + " is out of " + requiredQuestNodeID + " Node");
        //}
    }



}