﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;
using UnityEngine.Events;
using PixelCrushers;
using PixelCrushers.QuestMachine;


public class QuestTrackListener : MonoBehaviour, IMessageHandler
{

    public StringField requiredQuestID;
    public QuestNodeListener[] QuestNodeListeners;

    [Space]
    public UnityEvent OnQuestTracked;
    public UnityEvent OnQuestNotTracked;

    void OnEnable()
    {
        // Listen for "Quest Track Toggle Changed" messages:
        MessageSystem.AddListener(this, QuestMachineMessages.QuestTrackToggleChangedMessage, requiredQuestID);

    }

    void OnDisable()
    {
        // Stop listening:
        MessageSystem.RemoveListener(this);
    }

    public void OnMessage(MessageArgs messageArgs)
    {
        // A quest's tracking was just turned on or off.
        string questID = messageArgs.parameter;
        bool isTracked = (bool)messageArgs.values[0];

        if (isTracked)
        {
   

            OnQuestTracked.Invoke();
            Debug.Log(requiredQuestID + " is Tracked");

            for (int i = 0; i < QuestNodeListeners.Length; i++)
            {
                QuestNodeListeners[i].CheckIfNodeIsActive();
            }

        }
        else
        {
            OnQuestNotTracked.Invoke();
            Debug.Log(requiredQuestID + " is not Tracked");
        }




    }




}
